You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by gi...@apache.org on 2014/01/08 14:53:28 UTC

git commit: updated refs/heads/master to e58c3c8

Updated Branches:
  refs/heads/master 3e45dfb94 -> e58c3c809


CLOUDSTACK-5619: Egress Firewall rules - Increased timeout for router to come up


Project: http://git-wip-us.apache.org/repos/asf/cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/cloudstack/commit/e58c3c80
Tree: http://git-wip-us.apache.org/repos/asf/cloudstack/tree/e58c3c80
Diff: http://git-wip-us.apache.org/repos/asf/cloudstack/diff/e58c3c80

Branch: refs/heads/master
Commit: e58c3c809d4063e46e5e1c1f594763e2488bec30
Parents: 3e45dfb
Author: Ashutosh K <as...@clogeny.com>
Authored: Wed Jan 8 19:22:07 2014 +0530
Committer: Girish Shilamkar <gi...@clogeny.com>
Committed: Wed Jan 8 19:22:07 2014 +0530

----------------------------------------------------------------------
 test/integration/component/test_egress_fw_rules.py | 10 ++++------
 1 file changed, 4 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cloudstack/blob/e58c3c80/test/integration/component/test_egress_fw_rules.py
----------------------------------------------------------------------
diff --git a/test/integration/component/test_egress_fw_rules.py b/test/integration/component/test_egress_fw_rules.py
index 6c0bfd2..e1568bd 100644
--- a/test/integration/component/test_egress_fw_rules.py
+++ b/test/integration/component/test_egress_fw_rules.py
@@ -291,8 +291,8 @@ class TestEgressFWRules(cloudstackTestCase):
             self.debug("%s %s" % (script_file, exec_cmd_params))
 
             exec_success = False
-            #Timeout set to 6 minutes
-            timeout = 360
+            #Timeout set to 12 minutes
+            timeout = 720
             while timeout:
                 self.debug('sleep %s seconds for egress rule to affect on Router.' % self.services['sleep'])
                 time.sleep(self.services['sleep'])
@@ -304,17 +304,15 @@ class TestEgressFWRules(cloudstackTestCase):
                     exec_success = True
                     break
                 else:
-                    if result == []:
-                        self.fail("Router is not accessible")
                     # This means router network did not come up as yet loop back.
-                    if "send" in result[0]:
+                    if ((result == []) or ("send" in result[0])):
                         timeout -= self.services['sleep']
                     else: # Failed due to some other error
                         break
             #end while
 
             if timeout == 0:
-                self.fail("Router network failed to come up after 6 minutes.")
+                self.fail("Router network failed to come up after 12 minutes.")
 
             ssh.execute('rm -rf %s' % script_file)